goscript

package
v0.0.0-...-6d64a81 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2016 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GoScript

type GoScript struct {
	*exec.Cmd
	// contains filtered or unexported fields
}

GoScript type

func NewFromFile

func NewFromFile(sourcePath string, args ...string) (*GoScript, error)

NewFromFile takes in a filePath of golang source and converts it into a GoScript type with an embedded exec.Cmd

func NewFromString

func NewFromString(source string, args ...string) (*GoScript, error)

NewFromString takes in a string of golang source and converts into a GoScript type with an embedded exec.Cmd

func (GoScript) Clean

func (gs GoScript) Clean() error

Clean deletes the generated goscript tempfile

func (GoScript) FilePath

func (gs GoScript) FilePath() string

FilePath returns the current GoScipt's file path

Jump to