Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GoScript ¶
GoScript type
func NewFromFile ¶
NewFromFile takes in a filePath of golang source and converts it into a GoScript type with an embedded exec.Cmd
func NewFromString ¶
NewFromString takes in a string of golang source and converts into a GoScript type with an embedded exec.Cmd
Click to show internal directories.
Click to hide internal directories.